"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const react_native_1 = require("react-native");
const utils_1 = require("../utils");
function useDimensions(props) {
    const { staticDimension, maxDimension, horizontal, onLayout, adjustGridToStyles, contentContainerStyle, style, itemDimension, spacing, fixed, maxItemsPerRow, } = props;
    const [totalDimension, setTotalDimension] = (0, react_1.useState)(() => {
        let defaultTotalDimension = staticDimension;
        if (!staticDimension) {
            const dimension = horizontal ? 'height' : 'width';
            defaultTotalDimension = (0, utils_1.getAdjustedTotalDimensions)({
                totalDimension: react_native_1.Dimensions.get('window')[dimension],
                maxDimension,
                contentContainerStyle,
                style,
                horizontal,
                adjustGridToStyles,
            });
        }
        return defaultTotalDimension;
    });
    const onLayoutLocal = (0, react_1.useCallback)((e) => {
        if (!staticDimension) {
            const { width, height } = e.nativeEvent.layout || {};
            let newTotalDimension = horizontal ? height : width;
            newTotalDimension = (0, utils_1.getAdjustedTotalDimensions)({
                totalDimension: newTotalDimension,
                maxDimension,
                contentContainerStyle,
                style,
                horizontal,
                adjustGridToStyles,
            });
            if (totalDimension !== newTotalDimension && newTotalDimension > 0) {
                setTotalDimension(newTotalDimension);
            }
        }
        // call onLayout prop if passed
        if (onLayout) {
            onLayout(e);
        }
    }, [staticDimension, maxDimension, totalDimension, horizontal, onLayout, adjustGridToStyles, contentContainerStyle, style]);
    const { containerDimension, itemsPerRow, fixedSpacing } = (0, react_1.useMemo)(() => (0, utils_1.calculateDimensions)({
        itemDimension,
        staticDimension,
        totalDimension,
        spacing,
        fixed,
        maxItemsPerRow,
    }), [itemDimension, staticDimension, totalDimension, spacing, fixed, maxItemsPerRow]);
    return {
        totalDimension,
        onLayout: onLayoutLocal,
        containerDimension,
        itemsPerRow,
        fixedSpacing,
    };
}
exports.default = useDimensions;
